@@ -13,20 +13,21 @@
 
 namespace KWayland
 {
-    namespace Client
-    {
-        class BlurManager;
-        class ContrastManager;
-        class Compositor;
-        class ConnectionThread;
-        class PlasmaWindowManagement;
-        class PlasmaShell;
-        class Registry;
-        class ShadowManager;
-        class ShmPool;
-        class SlideManager;
-    }
+namespace Client
+{
+class BlurManager;
+class ContrastManager;
+class Compositor;
+class ConnectionThread;
+class PlasmaWindowManagement;
+class PlasmaShell;
+class Registry;
+class ShadowManager;
+class ShmPool;
+class SlideManager;
 }
+}
+class WaylandXdgActivationV1;
 
 class WaylandIntegration : public QObject
 {
@@ -45,7 +46,8 @@ public:
     KWayland::Client::Compositor *waylandCompositor() const;
     KWayland::Client::PlasmaWindowManagement *plasmaWindowManagement();
     KWayland::Client::PlasmaShell *waylandPlasmaShell();
-    KWayland::Client::ShmPool *waylandShmPool();
+    KWayland::Client::ShmPool *createShmPool();
+    WaylandXdgActivationV1 *activation();
 
 private:
     QPointer<KWayland::Client::ConnectionThread> m_waylandConnection;
@@ -57,7 +59,11 @@ private:
     QPointer<KWayland::Client::ShadowManager> m_waylandShadowManager;
     QPointer<KWayland::Client::PlasmaWindowManagement> m_wm;
     QPointer<KWayland::Client::PlasmaShell> m_waylandPlasmaShell;
-    QPointer<KWayland::Client::ShmPool> m_waylandShmPool;
+    QPointer<WaylandXdgActivationV1> m_activation;
+    struct {
+        quint32 name = 0;
+        quint32 version = 0;
+    } m_activationInterface;
 };
 
 #endif
